@@ -1,11 +1,14 @@
 package Log::Any::Adapter::Catalyst;
-use Log::Any::Adapter::Util qw(make_method);
+
+# ABSTRACT: Enable error and status logging in Catalyst Models via Log::Any
+
 use strict;
 use warnings;
 use Carp;
+use Log::Any::Adapter::Util qw(make_method);
 use base qw(Log::Any::Adapter::Base);
 
-our $VERSION = '0.11';
+our $VERSION = '1.00';
 
 sub init {
     my ($self) = @_;
@@ -41,6 +44,10 @@ __END__
 
 Log::Any::Adapter::Catalyst - Enable error and status logging in Catalyst Models via Log::Any
 
+=head1 VERSION
+
+version 1.00
+
 =head1 SYNOPSIS
 
 In a Catalyst Model, View, etc (anywhere you don't have C<$c>):
@@ -82,13 +89,13 @@ L<Catalyst|Catalyst>, L<Catalyst::Log|Catalyst::Log>
 
 =head1 AUTHOR
 
-Mark Grimes
+Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>
 
-=head1 COPYRIGHT & LICENSE
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011 Mark Grimes, all rights reserved.
+This software is copyright (c) 2014 by Mark Grimes, E<lt>mgrimes@cpan.orgE<gt>.
 
-This program is free software; you can redistribute it and/or modify it under
-the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
